@@ -306,6 +306,11 @@ class FieldConverterMixin:
                         {"type": "object", "nullable": True},
                         {"$ref": ret.pop("$ref")},
                     ]
+                elif "allOf" in ret:
+                    attributes["anyOf"] = [
+                        *ret.pop("allOf"),
+                        {"type": "object", "nullable": True},
+                    ]
                 else:
                     attributes["nullable"] = True
             else:
@@ -313,7 +318,7 @@ class FieldConverterMixin:
                     attributes["anyOf"] = [{"$ref": ret.pop("$ref")}, {"type": "null"}]
                 elif "allOf" in ret:
                     attributes["anyOf"] = [*ret.pop("allOf"), {"type": "null"}]
-                else:
+                elif "type" in ret:
                     attributes["type"] = [*make_type_list(ret.get("type")), "null"]
         return attributes
 
@@ -460,7 +465,17 @@ class FieldConverterMixin:
             field, marshmallow.fields.Pluck
         ):
             schema_dict = self.resolve_nested_schema(field.schema)  # type:ignore
-            if ret and "$ref" in schema_dict:
+            if (
+                ret
+                and "$ref" in schema_dict
+                and (
+                    self.openapi_version.major < 3
+                    or (
+                        self.openapi_version.major == 3
+                        and self.openapi_version.minor == 0
+                    )
+                )
+            ):
                 ret.update({"allOf": [schema_dict]})
             else:
                 ret.update(schema_dict)
