@@ -19,7 +19,6 @@ def test_field2choices_preserving_order(openapi):
     ("FieldClass", "jsontype"),
     [
         (fields.Integer, "integer"),
-        (fields.Number, "number"),
         (fields.Float, "number"),
         (fields.String, "string"),
         (fields.Str, "string"),
@@ -46,9 +45,8 @@ def test_field2property_type(FieldClass, jsontype, spec_fixture):
     assert res["type"] == jsontype
 
 
-@pytest.mark.parametrize("FieldClass", [fields.Field, fields.Raw])
-def test_field2property_no_type_(FieldClass, spec_fixture):
-    field = FieldClass()
+def test_field2property_no_type(spec_fixture):
+    field = fields.Raw()
     res = spec_fixture.openapi.field2property(field)
     assert "type" not in res
 
@@ -199,6 +197,20 @@ def test_field_with_allow_none(spec_fixture):
         assert res["type"] == ["string", "null"]
 
 
+@pytest.mark.parametrize("spec_fixture", ("2.0", "3.0.0", "3.1.0"), indirect=True)
+@pytest.mark.parametrize("field_class", [fields.Field, fields.Raw])
+def test_nullable_field_with_no_type(spec_fixture, field_class):
+    field = field_class(allow_none=True)
+    res = spec_fixture.openapi.field2property(field)
+    if spec_fixture.openapi.openapi_version.major < 3:
+        assert res["x-nullable"] is True
+    elif spec_fixture.openapi.openapi_version.minor < 1:
+        assert res["nullable"] is True
+    else:
+        assert "nullable" not in res
+        assert "type" not in res
+
+
 @pytest.mark.parametrize("spec_fixture", ("2.0", "3.0.0", "3.1.0"), indirect=True)
 def test_nested_nullable(spec_fixture):
     class Child(Schema):
@@ -222,6 +234,42 @@ def test_nested_nullable(spec_fixture):
         }
 
 
+@pytest.mark.parametrize("spec_fixture", ("2.0", "3.0.0", "3.1.0"), indirect=True)
+def test_nested_nullable_with_metadata(spec_fixture):
+    # Regression test for https://github.com/marshmallow-code/apispec/issues/955
+    class Child(Schema):
+        name = fields.Str()
+
+    field = fields.Nested(
+        Child,
+        allow_none=True,
+        metadata={"description": "foo"},
+    )
+    res = spec_fixture.openapi.field2property(field)
+    version = spec_fixture.openapi.openapi_version
+    if version.major < 3:
+        assert res == {
+            "allOf": [
+                {"$ref": "#/definitions/Child"},
+            ],
+            "x-nullable": True,
+            "description": "foo",
+        }
+    elif version.major == 3 and version.minor < 1:
+        assert res == {
+            "anyOf": [
+                {"$ref": "#/components/schemas/Child"},
+                {"type": "object", "nullable": True},
+            ],
+            "description": "foo",
+        }
+    else:
+        assert res == {
+            "anyOf": [{"$ref": "#/components/schemas/Child"}, {"type": "null"}],
+            "description": "foo",
+        }
+
+
 @pytest.mark.parametrize("spec_fixture", ("2.0", "3.0.0", "3.1.0"), indirect=True)
 def test_nullable_pluck(spec_fixture):
     class Example(Schema):
@@ -255,14 +303,14 @@ def test_field_with_load_only(spec_fixture):
 
 
 def test_field_with_range_no_type(spec_fixture):
-    field = fields.Field(validate=validate.Range(min=1, max=10))
+    field = fields.Raw(validate=validate.Range(min=1, max=10))
     res = spec_fixture.openapi.field2property(field)
     assert res["x-minimum"] == 1
     assert res["x-maximum"] == 10
     assert "type" not in res
 
 
-@pytest.mark.parametrize("field", (fields.Number, fields.Integer))
+@pytest.mark.parametrize("field", (fields.Float, fields.Integer))
 def test_field_with_range_string_type(spec_fixture, field):
     field = field(validate=validate.Range(min=1, max=10))
     res = spec_fixture.openapi.field2property(field)
@@ -387,10 +435,13 @@ def test_nullable_enum_returns_only_one_none(spec_fixture):
     assert ret["enum"] == [1, 2, None]
 
 
+@pytest.mark.parametrize("spec_fixture", ("2.0", "3.0.0", "3.1.0"), indirect=True)
 def test_field2property_nested_spec_metadatas(spec_fixture):
-    spec_fixture.spec.components.schema("Category", schema=CategorySchema)
+    class Child(Schema):
+        name = fields.Str()
+
     category = fields.Nested(
-        CategorySchema,
+        Child,
         metadata={
             "description": "A category",
             "invalid_property": "not in the result",
@@ -398,11 +449,19 @@ def test_field2property_nested_spec_metadatas(spec_fixture):
         },
     )
     result = spec_fixture.openapi.field2property(category)
-    assert result == {
-        "allOf": [build_ref(spec_fixture.spec, "schema", "Category")],
-        "description": "A category",
-        "x-extension": "A great extension",
-    }
+    version = spec_fixture.openapi.openapi_version
+    if version.major < 3 or version.minor < 1:
+        assert result == {
+            "allOf": [build_ref(spec_fixture.spec, "schema", "Child")],
+            "description": "A category",
+            "x-extension": "A great extension",
+        }
+    else:
+        assert result == {
+            **build_ref(spec_fixture.spec, "schema", "Child"),
+            "description": "A category",
+            "x-extension": "A great extension",
+        }
 
 
 def test_field2property_nested_spec(spec_fixture):
