@@ -1,15 +1,14 @@
 from datetime import datetime
 
 import pytest
-
-from marshmallow import EXCLUDE, fields, INCLUDE, RAISE, Schema, validate
-
-from apispec.ext.marshmallow import MarshmallowPlugin, OpenAPIConverter
-from apispec import exceptions, APISpec
+from marshmallow import EXCLUDE, INCLUDE, RAISE, Schema, fields, validate
 from packaging.version import Version
 
+from apispec import APISpec, exceptions
+from apispec.ext.marshmallow import MarshmallowPlugin, OpenAPIConverter
+
 from .schemas import CustomList, CustomStringField
-from .utils import get_schemas, build_ref, validate_spec
+from .utils import build_ref, get_schemas, validate_spec
 
 
 class TestMarshmallowFieldToOpenAPI:
@@ -40,13 +39,13 @@ class TestMarshmallowFieldToOpenAPI:
         res = openapi.schema2parameters(schema=UserSchema(), location="query")
         assert len(res) == 0
 
-        class UserSchema(Schema):
+        class UserSchema2(Schema):
             name = fields.Str()
 
             class Meta:
                 dump_only = ("name",)
 
-        res = openapi.schema2parameters(schema=UserSchema(), location="query")
+        res = openapi.schema2parameters(schema=UserSchema2(), location="query")
         assert len(res) == 0
 
 
@@ -213,7 +212,7 @@ class TestMarshmallowSchemaToParameters:
         class DelimitedList(fields.List):
             """Delimited list field"""
 
-        def delimited_list2param(self, field, **kwargs):
+        def delimited_list2param(self, field: fields.Field, **kwargs) -> dict:
             ret: dict = {}
             if isinstance(field, DelimitedList):
                 if self.openapi_version.major < 3:
@@ -245,6 +244,11 @@ class TestMarshmallowSchemaToParameters:
         res = openapi._field2parameter(field, name="field", location="query")
         assert res["required"] is True
 
+    def test_field_deprecated(self, openapi):
+        field = fields.Str(metadata={"deprecated": True})
+        res = openapi._field2parameter(field, name="field", location="query")
+        assert res["deprecated"] is True
+
     def test_schema_partial(self, openapi):
         class UserSchema(Schema):
             field = fields.Str(required=True)
@@ -489,6 +493,7 @@ def test_openapi_tools_validate_v2():
         title="Pets", version="0.1", plugins=(ma_plugin,), openapi_version="2.0"
     )
     openapi = ma_plugin.converter
+    assert openapi is not None
 
     spec.components.schema("Category", schema=CategorySchema)
     spec.components.schema("Pet", {"discriminator": "name"}, schema=PetSchema)
@@ -546,6 +551,7 @@ def test_openapi_tools_validate_v3():
         title="Pets", version="0.1", plugins=(ma_plugin,), openapi_version="3.0.0"
     )
     openapi = ma_plugin.converter
+    assert openapi is not None
 
     spec.components.schema("Category", schema=CategorySchema)
     spec.components.schema("Pet", schema=PetSchema)
@@ -610,8 +616,9 @@ def test_openapi_tools_validate_v3():
 
 
 def test_openapi_converter_openapi_version_types():
-    converter_with_version = OpenAPIConverter(Version("3.1"), None, None)
-    converter_with_str_version = OpenAPIConverter("3.1", None, None)
+    spec = APISpec(title="Pets", version="0.1", openapi_version="2.0")
+    converter_with_version = OpenAPIConverter(Version("3.1"), None, spec)
+    converter_with_str_version = OpenAPIConverter("3.1", None, spec)
     assert (
         converter_with_version.openapi_version
         == converter_with_str_version.openapi_version
